// This file is released under the 3-clause BSD license. See COPYING-BSD.
//=================================

//Загрузка визуального моделироания
loadXcosLibs();
loadScicos();

//Загрузка диаграммы
[a, pathlib] = libraryinfo("nonequilibrim_processlib");
clear a;
assert_checktrue(importXcosDiagram(pathlib + "/tests/ConChemicalReactionsStreams.zcos"));
clear pathlib;

//Исходные данные для расчетов
nu11 = 1.11;
nu12 = 1.17;
nu13 = 2.13;
nu14 = 1.53;
nu15 = 3.57;
nu21 = 2.31;
nu22 = 1.47;
nu23 = 4.23;
nu24 = 5.13;
nu25 = 6.57;
nu26 = 8.13;
nu27 = 9.57;
nu31 = 4.71;
nu32 = 4.77;
nu33 = 5.13;
nu34 = 1.83;
nu35 = 3.27;
muA1 = 19.5;
muA2 = 21.3;
muA3 = 14.7;
muA4 = 9.3;
muA5 = 8.1;
muB1 = 14.5;
muB2 = 24.3;
muB3 = 11.7;
muB4 = 12.3;
muB5 = 5.1;
muC1 = 22.5;
muC2 = 30.3;
Tmix = 300;
R1 = 10.53;
R12 = 0.15;
R21 = 0.183;
R2 = 9.81;
R3 = 5.13;
nu1A1 = 1.329;
nu2A1 = 4.329;
nu1A5 = 1.653;
nu2A5 = 4.653;
nuB3 = 7.029;
st1A1 = 4.029;
st2A1 = 1.35;
st1A5 = 2.13;
st2A5 = 5.163;
stB3 = 3.021;

//Контрольные расчетные значения
tXdep1 = (293.15 / Tmix) * (nu11*muA1 + nu12*muA2 + nu13*muA3 - nu14*muA4 - nu15*muA5);//Сродство химической реакции 1
tXdep2 = (293.15 / Tmix) * (nu21*muB1 + nu22*muA3 + nu23*muB2 + nu24*muA5 - nu25*muB3 - nu26*muB4 - nu27*muB5);//Сродство химической реакции 2
tXdep3 = (293.15 / Tmix) * (nu31*muC1 + nu32*muA3 + nu33*muC2 - nu34*muB3 - nu35*muA5);//Сродство химической реакции 3
tvdep1 = R1*tXdep1 + R12*tXdep2;//Скорость реакции 1
tvdep2 = R21*tXdep1 + R2*tXdep2;//Скорость реакции 2
tvdep3 = R3*tXdep3;//Скорость реакции 3
tvQnek1 = (nu11*muA1 + nu12*muA2 + nu13*muA3 - nu14*muA4 - nu15*muA5)*tvdep1;//Cкорость выделения некомпенсированной теплоты реакции 1
tvQnek2 = (nu21*muB1 + nu22*muA3 + nu23*muB2 + nu24*muA5 - nu25*muB3 - nu26*muB4 - nu27*muB5)*tvdep2;//Cкорость выделения некомпенсированной теплоты реакции 2
tvQnek3 = (nu31*muC1 + nu32*muA3 + nu33*muC2 - nu34*muB3 - nu35*muA5)*tvdep3;//Cкорость выделения некомпенсированной теплоты реакции 3
tvmolA1 = -nu11*tvdep1 + nu1A1*st1A1 + nu2A1*st2A1;//Скорость изменения количества вещества A1
tvmolA2 = -nu12*tvdep1;//Скорость изменения количества вещества A2
tvmolA3 = -nu13*tvdep1 - nu22*tvdep2 - nu32*tvdep3;//Скорость изменения количества вещества A3
tvmolA4 = nu14*tvdep1;//Скорость изменения количества вещества A4
tvmolA5 = nu15*tvdep1 - nu24*tvdep2 + nu35*tvdep3 - nu1A5*st1A5 - nu2A5*st2A5;//Скорость изменения количества вещества A5
tvmolB1 = -nu21*tvdep2;//Скорость изменения количества вещества B1
tvmolB2 = -nu23*tvdep2;//Скорость изменения количества вещества B2
tvmolB3 = nu25*tvdep2 + nu34*tvdep3 - nuB3*stB3;//Скорость изменения количества вещества B3
tvmolB4 = nu26*tvdep2;//Скорость изменения количества вещества B4
tvmolB5 = nu27*tvdep2;//Скорость изменения количества вещества B5
tvmolC1 = -nu31*tvdep3;//Скорость изменения количества вещества C1
tvmolC2 = -nu33*tvdep3;//Скорость изменения количества вещества C2

//Вычисление тестируемых значений
scicos_simulate(scs_m);
clear scs_m;

//Проверка
assert_checkalmostequal([Xdep1.values, Xdep2.values, Xdep3.values,...
                         vdep1.values, vdep2.values, vdep3.values,...
                         vQnek1.values, vQnek2.values, vQnek3.values,...
                         vmolA1.values, vmolA2.values, vmolA3.values, vmolA4.values, vmolA5.values,...
                         vmolB1.values, vmolB2.values, vmolB3.values, vmolB4.values, vmolB5.values,...
                         vmolC1.values, vmolC2.values],...
                        [tXdep1, tXdep2, tXdep3,...
                         tvdep1, tvdep2, tvdep3,...
                         tvQnek1, tvQnek2, tvQnek3,...
                         tvmolA1, tvmolA2, tvmolA3, tvmolA4, tvmolA5,...
                         tvmolB1, tvmolB2, tvmolB3, tvmolB4, tvmolB5,...
                         tvmolC1, tvmolC2], 0.000001);

//Чистка
clear nu11;
clear nu12;
clear nu13;
clear nu14;
clear nu15;
clear nu21;
clear nu22;
clear nu23;
clear nu24;
clear nu25;
clear nu26;
clear nu27;
clear nu31;
clear nu32;
clear nu33;
clear nu34;
clear nu35;
clear muA1;
clear muA2;
clear muA3;
clear muA4;
clear muA5;
clear muB1;
clear muB2;
clear muB3;
clear muB4;
clear muB5;
clear muC1;
clear muC2;
clear Tmix;
clear R1;
clear R12;
clear R21;
clear R2;
clear R3;
clear nu1A1;
clear nu2A1;
clear nu1A5;
clear nu2A5;
clear nuB3;
clear st1A1;
clear st2A1;
clear st1A5;
clear st2A5;
clear stB3;

clear tXdep1;
clear tXdep2;
clear tXdep3;
clear tvdep1;
clear tvdep2;
clear tvdep3;
clear tvQnek1;
clear tvQnek2;
clear tvQnek3;
clear tvmolA1;
clear tvmolA2;
clear tvmolA3;
clear tvmolA4;
clear tvmolA5;
clear tvmolB1;
clear tvmolB2;
clear tvmolB3;
clear tvmolB4;
clear tvmolB5;
clear tvmolC1;
clear tvmolC2;

clear Xdep1;
clear Xdep2;
clear Xdep3;
clear vdep1;
clear vdep2;
clear vdep3;
clear vQnek1;
clear vQnek2;
clear vQnek3;
clear vmolA1;
clear vmolA2;
clear vmolA3;
clear vmolA4;
clear vmolA5;
clear vmolB1;
clear vmolB2;
clear vmolB3;
clear vmolB4;
clear vmolB5;
clear vmolC1;
clear vmolC2;
