// This file is released under the 3-clause BSD license. See COPYING-BSD.
//=================================

//Загрузка визуального моделироания
loadXcosLibs();
loadScicos();

//Загрузка диаграммы
[a, pathlib] = libraryinfo("nonequilibrim_processlib");
clear a;
assert_checktrue(importXcosDiagram(pathlib + "/tests/ConChemicalReactionsTwoTemperatures.zcos"));
clear pathlib;

//Исходные данные для расчетов
nu11 = 1.17;
nu12 = 4.17;
nu13 = 5.13;
nu14 = 1.83;
nu15 = 6.57;
nu21 = 8.31;
nu22 = 4.47;
nu23 = 1.23;
nu24 = 2.13;
nu25 = 3.57;
nu26 = 5.13;
nu27 = 6.57;
nu31 = 1.71;
nu32 = 1.77;
nu33 = 8.13;
nu34 = 4.83;
nu35 = 9.27;
muA1 = 13.5;
muA2 = 33.3;
muA3 = 11.7;
muA4 = 6.3;
muA5 = 5.1;
muB1 = 11.7;
muB2 = 27.3;
muB3 = 14.7;
muB4 = 15.3;
muB5 = 8.1;
muC1 = 25.5;
muC2 = 39.3;
Tmix1 = 390;
Tmix2 = 273;
TRes = 369;
Beta1 = 0.75;
Beta2 = 0.63;
Beta3 = 0.39;
R1 = 13.53;
R12 = 0.75;
R21 = 0.783;
R2 = 12.81;
R3 = 8.13;
K21 = 51.3;
K1Res = 27.3;

//Контрольные расчетные значения
tXdep1 = 293.15 * (Beta1 / Tmix1 + (1 - Beta1) / Tmix2) * (nu11*muA1 + nu12*muA2 + nu13*muA3 - nu14*muA4 - nu15*muA5);//Сродство химической реакции 1
tXdep2 = 293.15 * (Beta2 / Tmix1 + (1 - Beta2) / Tmix2) * (nu21*muB1 + nu22*muA3 + nu23*muB2 + nu24*muA5 - nu25*muB3 - nu26*muB4 - nu27*muB5);//Сродство химической реакции 2
tXdep3 = 293.15 * (Beta3 / Tmix1 + (1 - Beta3) / Tmix2) * (nu31*muC1 + nu32*muA3 + nu33*muC2 - nu34*muB3 - nu35*muA5);//Сродство химической реакции 3
tXQper21 = (293.15 / Tmix1 - 293.15 / Tmix2);//Разность температур между смесями 2 и 1
tXQper1Res = (293.15 / TRes - 293.15 / Tmix1);//Разность температур между смесью 1 и резервуаром
timuR1Mix1 = nu11*muA1 + nu12*muA2 + nu13*muA3;//Воздействие реакции 1 смесь 1
timuR1Mix2 = -(nu14*muA4 + nu15*muA5);//Воздействие реакции 1 смесь 2
timuR2Mix1 = nu21*muB1 + nu22*muA3 + nu23*muB2 - nu25*muB3;//Воздействие реакции 2 смесь 1
timuR2Mix2 = nu24*muA5 - nu26*muB4 - nu27*muB5;//Воздействие реакции 2 смесь 2
timuR3Mix1 = nu31*muC1 + nu32*muA3 - nu34*muB3;//Воздействие реакции 3 смесь 1
timuR3Mix2 = nu33*muC2 - nu35*muA5;//Воздействие реакции 3 смесь 2
tvdep1 = R1*tXdep1 + R12*tXdep2;//Скорость реакции 1
tvdep2 = R21*tXdep1 + R2*tXdep2;//Скорость реакции 2
tvdep3 = R3*tXdep3;//Скорость реакции 3
tvQper21 = K21*tXQper21;//Скорость переноса теплоты между отсеками 2 и 1
tvQper1Res = K1Res*tXQper1Res;//Скорость переноса теплоты между отсеком 1 и резервуаром
tvQnek1 = (nu11*muA1 + nu12*muA2 + nu13*muA3 - nu14*muA4 - nu15*muA5)*tvdep1;//Cкорость выделения некомпенсированной теплоты реакции 1
tvQnek2 = (nu21*muB1 + nu22*muA3 + nu23*muB2 + nu24*muA5 - nu25*muB3 - nu26*muB4 - nu27*muB5)*tvdep2;//Cкорость выделения некомпенсированной теплоты реакции 2
tvQnek3 = (nu31*muC1 + nu32*muA3 + nu33*muC2 - nu34*muB3 - nu35*muA5)*tvdep3;//Cкорость выделения некомпенсированной теплоты реакции 3
tvmolA1 = -nu11*tvdep1;//Скорость изменения количества вещества A1
tvmolA2 = -nu12*tvdep1;//Скорость изменения количества вещества A2
tvmolA3 = -nu13*tvdep1 - nu22*tvdep2 - nu32*tvdep3;//Скорость изменения количества вещества A3
tvmolA4 = nu14*tvdep1;//Скорость изменения количества вещества A4
tvmolA5 = nu15*tvdep1 - nu24*tvdep2 + nu35*tvdep3;//Скорость изменения количества вещества A5
tvmolB1 = -nu21*tvdep2;//Скорость изменения количества вещества B1
tvmolB2 = -nu23*tvdep2;//Скорость изменения количества вещества B2
tvmolB3 = nu25*tvdep2 + nu34*tvdep3;//Скорость изменения количества вещества B3
tvmolB4 = nu26*tvdep2;//Скорость изменения количества вещества B4
tvmolB5 = nu27*tvdep2;//Скорость изменения количества вещества B5
tvmolC1 = -nu31*tvdep3;//Скорость изменения количества вещества C1
tvmolC2 = -nu33*tvdep3;//Скорость изменения количества вещества C2
tvQMix1 = Beta1*tvQnek1 + Beta2*tvQnek2 + Beta3*tvQnek3 + tvQper21 - tvQper1Res;//Перенесенная теплота в смесь 1
tvQMix2 = (1 - Beta1)*tvQnek1 + (1 - Beta2)*tvQnek2 + (1 - Beta3)*tvQnek3 - tvQper21;//Перенесенная теплота в смесь 2
tvUMix1 = tvQMix1 + muA1*tvmolA1 + muA2*tvmolA2 + muA3*tvmolA3 + muB1*tvmolB1 + muB2*tvmolB2 + muB3*tvmolB3 + muC1*tvmolC1;//Скорость изменения внутренней энергии смеси 1
tvUMix2 = tvQMix2 + muA4*tvmolA4 + muA5*tvmolA5 + muB4*tvmolB4 + muB5*tvmolB5 + muC2*tvmolC2;//Скорость изменения внутренней энергии смеси 2
tvURes = tvQper1Res;//скорость изменения внутренней энергии резервуара

//Вычисление тестируемых значений
scicos_simulate(scs_m);
clear scs_m;

//Проверка
assert_checkalmostequal([Xdep1.values, Xdep2.values, Xdep3.values,...
                         XQper21.values, XQper1Res.values,...
                         imuR1Mix1.values, imuR2Mix1.values, imuR3Mix1.values,...
                         imuR1Mix2.values, imuR2Mix2.values, imuR3Mix2.values,...
                         vdep1.values, vdep2.values, vdep3.values,...
                         vQper21.values, vQper1Res.values,...
                         vQnek1.values, vQnek2.values, vQnek3.values,...
                         vmolA1.values, vmolA2.values, vmolA3.values, vmolA4.values, vmolA5.values,...
                         vmolB1.values, vmolB2.values, vmolB3.values, vmolB4.values, vmolB5.values,...
                         vmolC1.values, vmolC2.values,...
                         vQMix1.values, vQMix2.values,...
                         vUMix1.values, vUMix2.values, vURes.values],...
                        [tXdep1, tXdep2, tXdep3,...
                         tXQper21, tXQper1Res,...
                         timuR1Mix1, timuR2Mix1, timuR3Mix1,...
                         timuR1Mix2, timuR2Mix2, timuR3Mix2,...
                         tvdep1, tvdep2, tvdep3,...
                         tvQper21, tvQper1Res,...
                         tvQnek1, tvQnek2, tvQnek3,...
                         tvmolA1, tvmolA2, tvmolA3, tvmolA4, tvmolA5,...
                         tvmolB1, tvmolB2, tvmolB3, tvmolB4, tvmolB5,...
                         tvmolC1, tvmolC2,...
                         tvQMix1, tvQMix2,...
                         tvUMix1, tvUMix2, tvURes], 0.000001);
//Чистка
clear nu11;
clear nu12;
clear nu13;
clear nu14;
clear nu15;
clear nu21;
clear nu22;
clear nu23;
clear nu24;
clear nu25;
clear nu26;
clear nu27;
clear nu31;
clear nu32;
clear nu33;
clear nu34;
clear nu35;
clear muA1;
clear muA2;
clear muA3;
clear muA4;
clear muA5;
clear muB1;
clear muB2;
clear muB3;
clear muB4;
clear muB5;
clear muC1;
clear muC2;
clear Tmix1;
clear Tmix2;
clear TRes;
clear Beta1;
clear Beta2;
clear Beta3;
clear R1;
clear R12;
clear R21;
clear R2;
clear R3;
clear K21;
clear K1Res;

clear tXdep1;
clear tXdep2;
clear tXdep3;
clear tXQper21;
clear tXQper1Res;
clear timuR1Mix1;
clear timuR1Mix2;
clear timuR2Mix1;
clear timuR2Mix2;
clear timuR3Mix1;
clear timuR3Mix2;
clear tvdep1;
clear tvdep2;
clear tvdep3;
clear tvQper21;
clear tvQper1Res;
clear tvQnek1;
clear tvQnek2;
clear tvQnek3;
clear tvmolA1;
clear tvmolA2;
clear tvmolA3;
clear tvmolA4;
clear tvmolA5;
clear tvmolB1;
clear tvmolB2;
clear tvmolB3;
clear tvmolB4;
clear tvmolB5;
clear tvmolC1;
clear tvmolC2;
clear tvQMix1;
clear tvQMix2;
clear tvUMix1;
clear tvUMix2;
clear tvURes;

clear Xdep1;
clear Xdep2;
clear Xdep3;
clear XQper21;
clear XQper1Res;
clear imuR1Mix1;
clear imuR1Mix2;
clear imuR2Mix1;
clear imuR2Mix2;
clear imuR3Mix1;
clear imuR3Mix2;
clear vdep1;
clear vdep2;
clear vdep3;
clear vQper21;
clear vQper1Res;
clear vQnek1;
clear vQnek2;
clear vQnek3;
clear vmolA1;
clear vmolA2;
clear vmolA3;
clear vmolA4;
clear vmolA5;
clear vmolB1;
clear vmolB2;
clear vmolB3;
clear vmolB4;
clear vmolB5;
clear vmolC1;
clear vmolC2;
clear vQMix1;
clear vQMix2;
clear vUMix1;
clear vUMix2;
clear vURes;
