// This file is released under the 3-clause BSD license. See COPYING-BSD.
//=================================

//Загрузка визуального моделироания
loadXcosLibs();
loadScicos();

//Загрузка диаграммы
[a, pathlib] = libraryinfo("nonequilibrim_processlib");
clear a;
assert_checktrue(importXcosDiagram(pathlib + "/tests/ConChemicalReactionsTwoTemperaturesStreams.zcos"));
clear pathlib;

//Исходные данные для расчетов
nu11 = 4.41;
nu12 = 1.47;
nu13 = 6.43;
nu14 = 4.53;
nu15 = 3.57;
nu21 = 2.61;
nu22 = 1.77;
nu23 = 4.23;
nu24 = 5.43;
nu25 = 9.57;
nu26 = 5.13;
nu27 = 6.57;
nu31 = 1.71;
nu32 = 4.47;
nu33 = 2.49;
nu34 = 4.53;
nu35 = 6.57;
muA1 = 16.5;
muA2 = 24.3;
muA3 = 11.7;
muA4 = 6.3;
muA5 = 5.1;
muB1 = 11.5;
muB2 = 21.3;
muB3 = 14.7;
muB4 = 15.3;
muB5 = 8.1;
muC1 = 28.5;
muC2 = 30.3;
fiStr1Res = 48.3;
fiStr2Res = 54.3;
Tmix1 = 321;
Tmix2 = 240;
TRes = 360;
Beta1 = 0.75;
Beta2 = 0.63;
Beta3 = 0.27;
R1 = 13.53;
R12 = 0.45;
R21 = 0.483;
R2 = 9.51;
R3 = 5.53;
K21 = 54.3;
K1Res = 27.9;
nu1A1 = 1.629;
nu2A1 = 4.629;
nu1A5 = 1.353;
nu2A5 = 4.353;
nuB3 = 7.329;
st1A1 = 4.329;
st2A1 = 1.65;
st1A5 = 2.43;
st2A5 = 5.463;
stB3 = 3.621;
V1ResStr = 14.1;
V2ResStr = 20.7;
QMix1Str = 5.19;
QMix2Str = 2.49;
QResStr = 6.39;

//Контрольные расчетные значения
tXdep1 = 293.15 * (Beta1 / Tmix1 + (1 - Beta1) / Tmix2) * (nu11*muA1 + nu12*muA2 + nu13*muA3 - nu14*muA4 - nu15*muA5);//Сродство химической реакции 1
tXdep2 = 293.15 * (Beta2 / Tmix1 + (1 - Beta2) / Tmix2) * (nu21*muB1 + nu22*muA3 + nu23*muB2 + nu24*muA5 - nu25*muB3 - nu26*muB4 - nu27*muB5);//Сродство химической реакции 2
tXdep3 = 293.15 * (Beta3 / Tmix1 + (1 - Beta3) / Tmix2) * (nu31*muC1 + nu32*muA3 + nu33*muC2 - nu34*muB3 - nu35*muA5);//Сродство химической реакции 3
tXQper21 = (293.15 / Tmix1 - 293.15 / Tmix2);//Разность температур между смесями 2 и 1
tXQper1Res = (293.15 / TRes - 293.15 / Tmix1);//Разность температур между смесью 1 и резервуаром
timuR1Mix1 = nu11*muA1 + nu12*muA2 + nu13*muA3;//Воздействие реакции 1 смесь 1
timuR1Mix2 = -(nu14*muA4 + nu15*muA5);//Воздействие реакции 1 смесь 2
timuR2Mix1 = nu21*muB1 + nu22*muA3 + nu23*muB2 - nu25*muB3;//Воздействие реакции 2 смесь 1
timuR2Mix2 = nu24*muA5 - nu26*muB4 - nu27*muB5;//Воздействие реакции 2 смесь 2
timuR3Mix1 = nu31*muC1 + nu32*muA3 - nu34*muB3;//Воздействие реакции 3 смесь 1
timuR3Mix2 = nu33*muC2 - nu35*muA5;//Воздействие реакции 3 смесь 2
timust1Mix1 = -nu1A1*muA1;//Воздействие на внешний поток 1 смеси 1
timust2Mix1 = -nu2A1*muA1;//Воздействие на внешний поток 2 смеси 1
timust3Mix1 = nuB3*muB3;//Воздействие на внешний поток 3 смеси 1
timust1Mix2 = nu1A5*muA5;//Воздействие на внешний поток 1 смеси 2
timust2Mix2 = nu2A5*muA5;//Воздействие на внешний поток 2 смеси 2
tifist1Res = fiStr1Res;//Воздействие 1 резервуара на внешний поток
tifist2Res = -1.23*fiStr2Res;//Воздействие 2 резервуара на внешний поток
tvdep1 = R1*tXdep1 + R12*tXdep2;//Скорость реакции 1
tvdep2 = R21*tXdep1 + R2*tXdep2;//Скорость реакции 2
tvdep3 = R3*tXdep3;//Скорость реакции 3
tvQper21 = K21*tXQper21;//Скорость переноса теплоты между отсеками 2 и 1
tvQper1Res = K1Res*tXQper1Res;//Скорость переноса теплоты между отсеком 1 и резервуаром
tvQnek1 = (nu11*muA1 + nu12*muA2 + nu13*muA3 - nu14*muA4 - nu15*muA5)*tvdep1;//Cкорость выделения некомпенсированной теплоты реакции 1
tvQnek2 = (nu21*muB1 + nu22*muA3 + nu23*muB2 + nu24*muA5 - nu25*muB3 - nu26*muB4 - nu27*muB5)*tvdep2;//Cкорость выделения некомпенсированной теплоты реакции 2
tvQnek3 = (nu31*muC1 + nu32*muA3 + nu33*muC2 - nu34*muB3 - nu35*muA5)*tvdep3;//Cкорость выделения некомпенсированной теплоты реакции 3
tvmolA1 = -nu11*tvdep1 + nu1A1*st1A1 + nu2A1*st2A1;//Скорость изменения количества вещества A1
tvmolA2 = -nu12*tvdep1;//Скорость изменения количества вещества A2
tvmolA3 = -nu13*tvdep1 - nu22*tvdep2 - nu32*tvdep3;//Скорость изменения количества вещества A3
tvmolA4 = nu14*tvdep1;//Скорость изменения количества вещества A4
tvmolA5 = nu15*tvdep1 - nu24*tvdep2 + nu35*tvdep3 - nu1A5*st1A5 - nu2A5*st2A5;//Скорость изменения количества вещества A5
tvmolB1 = -nu21*tvdep2;//Скорость изменения количества вещества B1
tvmolB2 = -nu23*tvdep2;//Скорость изменения количества вещества B2
tvmolB3 = nu25*tvdep2 + nu34*tvdep3 - nuB3*stB3;//Скорость изменения количества вещества B3
tvmolB4 = nu26*tvdep2;//Скорость изменения количества вещества B4
tvmolB5 = nu27*tvdep2;//Скорость изменения количества вещества B5
tvmolC1 = -nu31*tvdep3;//Скорость изменения количества вещества C1
tvmolC2 = -nu33*tvdep3;//Скорость изменения количества вещества C2
tvQMix1 = Beta1*tvQnek1 + Beta2*tvQnek2 + Beta3*tvQnek3 + tvQper21 - tvQper1Res + QMix1Str;//Перенесенная теплота в смесь 1
tvQMix2 = (1 - Beta1)*tvQnek1 + (1 - Beta2)*tvQnek2 + (1 - Beta3)*tvQnek3 - tvQper21 + QMix2Str;//Перенесенная теплота в смесь 2
tvUMix1 = tvQMix1 + muA1*tvmolA1 + muA2*tvmolA2 + muA3*tvmolA3 + muB1*tvmolB1 + muB2*tvmolB2 + muB3*tvmolB3 + muC1*tvmolC1;//Скорость изменения внутренней энергии смеси 1
tvUMix2 = tvQMix2 + muA4*tvmolA4 + muA5*tvmolA5 + muB4*tvmolB4 + muB5*tvmolB5 + muC2*tvmolC2;//Скорость изменения внутренней энергии смеси 2
tvQRes = tvQper1Res + QResStr;//Скорость сообщения теплоты резервуару
tvURes = tvQRes - tifist1Res*V1ResStr - tifist2Res*V2ResStr;//скорость изменения внутренней энергии резервуара

//Вычисление тестируемых значений
scicos_simulate(scs_m);
clear scs_m;

//Проверка             
assert_checkalmostequal([Xdep1.values, Xdep2.values, Xdep3.values,...
                         XQper21.values, XQper1Res.values,...
                         imuR1Mix1.values, imuR2Mix1.values, imuR3Mix1.values,...
                         imuR1Mix2.values, imuR2Mix2.values, imuR3Mix2.values,...
                         imust1Mix1.values, imust2Mix1.values, imust3Mix1.values,...
                         imust1Mix2.values, imust2Mix2.values,...
                         ifist1Res.values, ifist2Res.values,...
                         vdep1.values, vdep2.values, vdep3.values,...
                         vQper21.values, vQper1Res.values,...
                         vQnek1.values, vQnek2.values, vQnek3.values,...
                         vmolA1.values, vmolA2.values, vmolA3.values, vmolA4.values, vmolA5.values,...
                         vmolB1.values, vmolB2.values, vmolB3.values, vmolB4.values, vmolB5.values,...
                         vmolC1.values, vmolC2.values,...
                         vQMix1.values, vQMix2.values,...
                         vUMix1.values, vUMix2.values,...
                         vQRes.values, vURes.values],...
                        [tXdep1, tXdep2, tXdep3,...
                         tXQper21, tXQper1Res,...
                         timuR1Mix1, timuR2Mix1, timuR3Mix1,...
                         timuR1Mix2, timuR2Mix2, timuR3Mix2,...
                         timust1Mix1, timust2Mix1, timust3Mix1,...
                         timust1Mix2, timust2Mix2,...
                         tifist1Res, tifist2Res,...
                         tvdep1, tvdep2, tvdep3,...
                         tvQper21, tvQper1Res,...
                         tvQnek1, tvQnek2, tvQnek3,...
                         tvmolA1, tvmolA2, tvmolA3, tvmolA4, tvmolA5,...
                         tvmolB1, tvmolB2, tvmolB3, tvmolB4, tvmolB5,...
                         tvmolC1, tvmolC2,...
                         tvQMix1, tvQMix2,...
                         tvUMix1, tvUMix2,...
                         tvQRes, tvURes], 0.000001);
                         
//Чистка
clear nu11;
clear nu12;
clear nu13;
clear nu14;
clear nu15;
clear nu21;
clear nu22;
clear nu23;
clear nu24;
clear nu25;
clear nu26;
clear nu27;
clear nu31;
clear nu32;
clear nu33;
clear nu34;
clear nu35;
clear muA1;
clear muA2;
clear muA3;
clear muA4;
clear muA5;
clear muB1;
clear muB2;
clear muB3;
clear muB4;
clear muB5;
clear muC1;
clear muC2;
clear fiStr1Res;
clear fiStr2Res;
clear Tmix1;
clear Tmix2;
clear TRes;
clear Beta1;
clear Beta2;
clear Beta3;
clear R1;
clear R12;
clear R21;
clear R2;
clear R3;
clear K21;
clear K1Res;
clear nu1A1;
clear nu2A1;
clear nu1A5;
clear nu2A5;
clear nuB3;
clear st1A1;
clear st2A1;
clear st1A5;
clear st2A5;
clear stB3;

clear tXdep1;
clear tXdep2;
clear tXdep3;
clear tXQper21;
clear tXQper1Res;
clear timuR1Mix1;
clear timuR1Mix2;
clear timuR2Mix1;
clear timuR2Mix2;
clear timuR3Mix1;
clear timuR3Mix2;
clear timust1Mix1;
clear timust1Mix2;
clear timust2Mix1;
clear timust2Mix2;
clear timust3Mix1;
clear tifist1Res;
clear tifist2Res;
clear tvdep1;
clear tvdep2;
clear tvdep3;
clear tvQper21;
clear tvQper1Res;
clear tvQnek1;
clear tvQnek2;
clear tvQnek3;
clear tvmolA1;
clear tvmolA2;
clear tvmolA3;
clear tvmolA4;
clear tvmolA5;
clear tvmolB1;
clear tvmolB2;
clear tvmolB3;
clear tvmolB4;
clear tvmolB5;
clear tvmolC1;
clear tvmolC2;
clear tvQMix1;
clear tvQMix2;
clear tvUMix1;
clear tvUMix2;
clear tvQRes;
clear tvURes;
clear tV1ResStr;
clear tV2ResStr;
clear tQMix1Str;
clear tQMix2Str;
clear tQResStr;

clear Xdep1;
clear Xdep2;
clear Xdep3;
clear XQper21;
clear XQper1Res;
clear imuR1Mix1;
clear imuR1Mix2;
clear imuR2Mix1;
clear imuR2Mix2;
clear imuR3Mix1;
clear imuR3Mix2;
clear imust1Mix1;
clear imust1Mix2;
clear imust2Mix1;
clear imust2Mix2;
clear imust3Mix1;
clear ifist1Res;
clear ifist2Res;
clear vdep1;
clear vdep2;
clear vdep3;
clear vQper21;
clear vQper1Res;
clear vQnek1;
clear vQnek2;
clear vQnek3;
clear vmolA1;
clear vmolA2;
clear vmolA3;
clear vmolA4;
clear vmolA5;
clear vmolB1;
clear vmolB2;
clear vmolB3;
clear vmolB4;
clear vmolB5;
clear vmolC1;
clear vmolC2;
clear vQMix1;
clear vQMix2;
clear vUMix1;
clear vUMix2;
clear vQRes;
clear vURes;
clear V1ResStr;
clear V2ResStr;
clear QMix1Str;
clear QMix2Str;
clear QResStr;
