// This file is released under the 3-clause BSD license. See COPYING-BSD.
//=================================

//Загрузка визуального моделироания
loadXcosLibs();
loadScicos();

//Загрузка диаграммы
[a, pathlib] = libraryinfo("nonequilibrim_processlib");
clear a;
assert_checktrue(importXcosDiagram(pathlib + "/tests/ConHeatTrans.zcos"));
clear pathlib;

//Исходные данные для расчетов
T1 = 290.7;
T2 = 309.15;
T3 = 315.39;
K12 = 3.9;
K1223 = 0.315;
K2312 = 0.645;
K23 = 6.9;

//Контрольные расчетные значения
tXQper12 = 293.15 / T1 - 293.15 / T2;//Разность обратных температур (отсеки 1 и 2)
tXQper23 = 293.15 / T2 - 293.15 / T3;//Разность обратных температур (отсеки 2 и 3)
tvQper12 = K12 * tXQper12 + K1223 * tXQper23;//Скорость переноса теплоты (отсеки 1 и 2)
tvQper23 = K2312 * tXQper12 + K23 * tXQper23;//Скорость переноса теплоты (отсеки 2 и 3)
tvU1 = tvQper12;//Скорость приращения внутренней энергии отсека 1
tvU2 = tvQper23 - tvQper12;//Скорость приращения внутренней энергии отсека 2
tvU3 = -tvQper23;//Скорость приращения внутренней энергии отсека 3

//Вычисление тестируемых значений
scicos_simulate(scs_m);
clear scs_m;

//Проверка
assert_checkalmostequal([XQper12.values, XQper23.values,...
						 vQper12.values, vQper23.values,...
						 vU1.values, vU2.values, vU3.values],...
						[tXQper12, tXQper23,...
						 tvQper12, tvQper23,...
						 tvU1, tvU2, tvU3], 0.000001);

//Чистка
clear T1;
clear T2;
clear T3;
clear K12;
clear K1223;
clear K2312;
clear K23;

clear tXQper12;
clear tXQper23;
clear tvQper12;
clear tvQper23;
clear tvU1;
clear tvU2;
clear tvU3;

clear XQper12;
clear XQper23;
clear vQper12;
clear vQper23;
clear vU1;
clear vU2;
clear vU3;
