// This file is released under the 3-clause BSD license. See COPYING-BSD.
//=================================

//Загрузка визуального моделироания
loadXcosLibs();
loadScicos();

//Загрузка диаграммы
[a, pathlib] = libraryinfo("nonequilibrim_processlib");
clear a;
assert_checktrue(importXcosDiagram(pathlib + "/tests/MemDifComp.zcos"));
clear pathlib;

//Исходные данные для расчетов
Tp = 290.7;
Tn = 303.3;
mup = 1.5;
mun = 2.1;
betap = 0.5;
betan = 0.5;
D = 1.11;
KD = 2.1;
K = 5.1;

//Контрольные расчетные значения
tDeltaT = 293.15 / Tp - 293.15 / Tn;//Разность обратных температур
tDeltaX = (293.15 * betap / Tp + 293.15 * betan / Tn)*(mun - mup);//Разность химиеских потенциалов
tvdx = D * tDeltaX + KD * tDeltaT;//Скорость диффузии
tvQper = KD * tDeltaX + K * tDeltaT;//Скорость переноса теплоты
tvQnek = (mun - mup) * tvdx;//Cкорость выделения некомпенсированной теплоты
tvQp = tvQper + betap*tvQnek;//Количество теплоты, полученное положительным отсеком
tvQn = -tvQper + betan*tvQnek;//Количество теплоты, полученное отрицательным отсеком
tvUp = tvQp + mup*tvdx;//Количество теплоты, полученное положительным отсеком
tvUn = tvQn - mun*tvdx;//Количество теплоты, полученное отрицательным отсеком
tvxp = tvdx;//Число молей компонента в положительном отсеке
tvxn = -tvdx;//Число молей компонента в отрицательном отсеке

//Вычисление тестируемых значений
scicos_simulate(scs_m);
clear scs_m;

//Проверка
assert_checkalmostequal([DeltaT.values, DeltaX.values,...
						 vdx.values, vQper.values, vQnek.values,...
						 vQp.values, vQn.values,...
						 vUp.values, vUn.values,...
						 vxp.values, vxn.values],...
						[tDeltaT, tDeltaX,...
						 tvdx, tvQper, tvQnek,...
						 tvQp, tvQn,...
						 tvUp, tvUn,...
						 tvxp, tvxn], 0.000001);

//Чистка
clear Tp;
clear Tn;
clear mup;
clear mun;
clear betap;
clear betan;
clear D;
clear KD;
clear K;

clear tDeltaT;
clear tDeltaX;
clear tvdx;
clear tvQper;
clear tvQnek;
clear tvQp;
clear tvQn;
clear tvUp;
clear tvUn;
clear tvxp;
clear tvxn;

clear DeltaT;
clear DeltaX;
clear vdx;
clear vQper;
clear vQnek;
clear vQp;
clear vQn;
clear vUp;
clear vUn;
clear vxp;
clear vxn;
