// This file is released under the 3-clause BSD license. See COPYING-BSD.
//=================================

//Загрузка визуального моделироания
loadXcosLibs();
loadScicos();

//Загрузка диаграммы
[a, pathlib] = libraryinfo("nonequilibrim_processlib");
clear a;
assert_checktrue(importXcosDiagram(pathlib + "/tests/MemDifCompHeat.zcos"));
clear pathlib;

//Исходные данные для расчетов
Tp = 288.3;
Tn = 309.3;
mup = 1.83;
mun = 2.55;
betap = 0.45;
betan = 0.55;
D = 4.11;
KD = 0.21;
K = 8.1;
QStream = 7.5;

//Контрольные расчетные значения
tDeltaT = 293.15 / Tp - 293.15 / Tn;//Разность обратных температур
tDeltaX = 293.15 * (betap / Tp + betan / Tn)*(mun - mup);//Разность химиеских потенциалов
tvdx = D * tDeltaX + KD * tDeltaT;//Скорость диффузии
tvQper = KD * tDeltaX + K * tDeltaT;//Скорость переноса теплоты
tvQnek = (mun - mup) * tvdx;//Cкорость выделения некомпенсированной теплоты
tvQp = tvQper + betap*tvQnek + QStream;//Количество теплоты, полученное положительным отсеком
tvQn = -tvQper + betan*tvQnek - QStream;//Количество теплоты, полученное отрицательным отсеком
tvxp = tvdx;//Число молей компонента в положительном отсеке
tvxn = -tvdx;//Число молей компонента в отрицательном отсеке
tvUp = tvQp + mup*tvxp;//Количество теплоты, полученное положительным отсеком
tvUn = tvQn + mun*tvxn;//Количество теплоты, полученное отрицательным отсеком

//Вычисление тестируемых значений
scicos_simulate(scs_m);
clear scs_m;

//Проверка
assert_checkalmostequal([DeltaT.values, DeltaX.values,...
						 vdx.values, vQper.values, vQnek.values,...
						 vQp.values, vQn.values,...
						 vUp.values, vUn.values,...
						 vxp.values, vxn.values],...
						[tDeltaT, tDeltaX,...
						 tvdx, tvQper, tvQnek,...
						 tvQp, tvQn,...
						 tvUp, tvUn,...
						 tvxp, tvxn], 0.000001);

//Чистка
clear Tp;
clear Tn;
clear mup;
clear mun;
clear betap;
clear betan;
clear D;
clear KD;
clear K;

clear tDeltaT;
clear tDeltaX;
clear tvdx;
clear tvQper;
clear tvQnek;
clear tvQp;
clear tvQn;
clear tvUp;
clear tvUn;
clear tvxp;
clear tvxn;

clear DeltaT;
clear DeltaX;
clear vdx;
clear vQper;
clear vQnek;
clear vQp;
clear vQn;
clear vUp;
clear vUn;
clear vxp;
clear vxn;
