// This file is released under the 3-clause BSD license. See COPYING-BSD.
//=================================

//Загрузка визуального моделироания
loadXcosLibs();
loadScicos();

//Загрузка диаграммы
[a, pathlib] = libraryinfo("nonequilibrim_processlib");
clear a;
assert_checktrue(importXcosDiagram(pathlib + "/tests/MemDifCompTwoSub.zcos"));
clear pathlib;

//Исходные данные для расчетов
TCom1 = 302.1;
TCom2 = 298.5;
Mu1Com1 = 3.87;
Mu1Com2 = 2.85;
Mu2Com1 = 2.49;
Mu2Com2 = 1.53;
BetaDiff1Com1 = 0.69;
BetaDiff2Com1 = 0.47;
BetaDiff1Com2 = 1 - BetaDiff1Com1;
BetaDiff2Com2 = 1 - BetaDiff2Com1;
SubStreamCom = -7.53;
QStreamCom = 13.89;
AHeatHeat = 14.1;
AHeatDiff1 = 0.63;
AHeatDiff2 = 0.45;
ADiff1Heat = 0.171;
ADiff1Diff1 = 15.3;
ADiff1Diff2 = 0.753;
ADiff2Heat = 0.471;
ADiff2Diff1 = 21.3;
ADiff2Diff2 = 0.783;

//Контрольные расчетные значения
tXQper = 293.15 / TCom2 - 293.15 / TCom1;//Разность обратных температур
tXDiff1 = 293.15 * (BetaDiff1Com1 / TCom1 + BetaDiff1Com2 / TCom2)*(Mu1Com1 - Mu1Com2);//Разность химических потенциалов вещества 1
tXDiff2 = 293.15 * (BetaDiff2Com1 / TCom1 + BetaDiff2Com2 / TCom2)*(Mu2Com1 - Mu2Com2);//Разность химических потенциалов вещества 2
tvQper = AHeatHeat * tXQper + AHeatDiff1 * tXDiff1 + AHeatDiff2 * tXDiff2;//Скорость переноса теплоты
tvDiff1 = ADiff1Heat * tXQper + ADiff1Diff1 * tXDiff1 + ADiff1Diff2 * tXDiff2;//Скорость диффузии вещества 1
tvDiff2 = ADiff2Heat * tXQper + ADiff2Diff1 * tXDiff1 + ADiff2Diff2 * tXDiff2;//Скорость диффузии вещества 2
tvQnekDiff1 = (Mu1Com1 - Mu1Com2) * tvDiff1;//Некомпенсированная теплота диффузии вещества 1
tvQnekDiff2 = (Mu2Com1 - Mu2Com2) * tvDiff2;//Некомпенсированная теплота диффузии вещества 2
tvQCom1 = -tvQper + BetaDiff1Com1*tvQnekDiff1 + BetaDiff2Com1*tvQnekDiff2 + QStreamCom;//Количество теплоты, полученное отсеком 1
tvQCom2 = tvQper + BetaDiff1Com2*tvQnekDiff1 + BetaDiff2Com2*tvQnekDiff2 - QStreamCom;//Количество теплоты, полученное отсеком 2
tvSub1Com1 = -tvDiff1; tvSub1Com2 = tvDiff1;//Изменения числел молей вещества 1 в отсеках
tvSub2Com1 = -tvDiff2 + SubStreamCom; tvSub2Com2 = tvDiff2 - SubStreamCom;//Изменения числел молей вещества 2 в отсеках
tvUCom1 = tvQCom1 + tvSub1Com1 * Mu1Com1 + tvSub2Com1 * Mu2Com1;//Внутренняя энергия отсека 1
tvUCom2 = tvQCom2 + tvSub1Com2 * Mu1Com2 + tvSub2Com2 * Mu2Com2;//Внутренняя энергия отсека 2

//Вычисление тестируемых значений
scicos_simulate(scs_m);
clear scs_m;

//Проверка
assert_checkalmostequal([XQper.values, XDiff1.values, XDiff2.values,...
                         vQper.values, vDiff1.values, vDiff2.values,...
                         vQnekDiff1.values, vQnekDiff2.values,...
                         vQCom1.values, vQCom2.values,...
                         vSub1Com1.values, vSub1Com2.values,...
                         vSub2Com1.values, vSub2Com2.values,...
                         vUCom1.values, vUCom2.values],...
                        [tXQper, tXDiff1, tXDiff2,...
                         tvQper, tvDiff1, tvDiff2,...
                         tvQnekDiff1, tvQnekDiff2,...
                         tvQCom1, tvQCom2,...
                         tvSub1Com1, tvSub1Com2,...
                         tvSub2Com1, tvSub2Com2,...
                         tvUCom1, tvUCom2], 0.000001);

//Чистка
clear TCom1;
clear TCom2;
clear Mu1Com1;
clear Mu1Com2;
clear Mu2Com1;
clear Mu2Com2;
clear BetaDiff1Com1;
clear BetaDiff2Com1;
clear BetaDiff1Com2;
clear BetaDiff2Com2;
clear SubStreamCom;
clear QStreamCom;
clear AHeatHeat;
clear AHeatDiff1;
clear AHeatDiff2;
clear ADiff1Heat;
clear ADiff1Diff1;
clear ADiff1Diff2;
clear ADiff2Heat;
clear ADiff2Diff1;
clear ADiff2Diff2;

clear tXQper;
clear tXDiff1;
clear tXDiff2;
clear tvQper;
clear tvDiff1;
clear tvDiff2;
clear tvQnekDiff1;
clear tvQnekDiff2;
clear tvQCom1;
clear tvQCom2;
clear tvSub1Com1;
clear tvSub2Com1;
clear tvSub1Com2;
clear tvSub2Com2;
clear tvUCom1;
clear tvUCom2;

clear XQper;
clear XDiff1;
clear XDiff2;
clear vQper;
clear vDiff1;
clear vDiff2;
clear vQnekDiff1;
clear vQnekDiff2;
clear vQCom1;
clear vQCom2;
clear vSub1Com1;
clear vSub2Com1;
clear vSub1Com2;
clear vSub2Com2;
clear vUCom1;
clear vUCom2;
